geowatch.utils.lightning\_ext.old\_parser\_devices module
=========================================================

.. automodule:: geowatch.utils.lightning_ext.old_parser_devices
   :members:
   :undoc-members:
   :show-inheritance:
